Some<T> class

Implemented types

Constructors

Some(T value)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
isNone bool
no setteroverride
isSome bool
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
final

Methods

and<U>(Option<U> other) Option<U>
override
andThen<U>(Option<U> toOption(T)) Option<U>
override
copy() Option<T>
override
expect(String message) → T
override
filter(bool predicate(T)) Option<T>
override
inspect(void onSome(T)) Option<T>
override
isNoneOr(bool test(T)) bool
override
isSomeAnd(bool test(T)) bool
override
map<U>(U toValue(T)) Option<U>
override
mapOr<U>(U defaultValue, U toValue(T)) → U
override
mapOrElse<U>(U onNone(), U toValue(T)) → U
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
okOr<E extends Exception>(E err) Result<T, E>
override
okOrElse<E extends Exception>(E onNone()) Result<T, E>
override
or(Option<T> other) Option<T>
override
orElse(Option<T> onNone()) Option<T>
override
toString() String
A string representation of this object.
inherited
unwrap() → T
override
unwrapOr(T defaultValue) → T
override
unwrapOrElse(T onNone()) → T
override
xor(Option<T> other) Option<T>
override
zip<U>(Option<U> other) Option<(T, U)>
override

Operators

operator ==(Object other) bool
The equality operator.
override